@@ -120,7 +120,7 @@ bool AnnotateDialog::parseCvsAnnotate(const QString &sandbox, const QString &rep
     cmdline += " ";
     cmdline += KShellProcess::quote(filename);
     // Hack because the string Annotations for blabla is
-    // print to stderr even with option -Q. Arg!
+    // printed to stderr even with option -Q. Arg!
     cmdline += " 2>&1";
 
     CvsProgressDialog l("Annotate", this);
@@ -134,7 +134,7 @@ bool AnnotateDialog::parseCvsAnnotate(const QString &sandbox, const QString &rep
 
     state = Begin;
     QCString line;
-    while ( l.getOneLine(&line) && (state != Finished) )
+    while (l.getOneLine(&line))
         {
             switch (state)
                 {
@@ -178,6 +178,8 @@ bool AnnotateDialog::parseCvsAnnotate(const QString &sandbox, const QString &rep
                 case Finished:
                     ;
                 }
+            if (state == Finished)
+                break;
         }
 
     //
