@@ -31,7 +31,8 @@ public:
     AnnotateView( QWidget *parent=0, const char *name=0 );
     ~AnnotateView();
 
-    void addLine(QString rev, QString author, QString date, QString content, QString comment, bool odd);
+    void addLine(const QString &rev, const QString &author, const QString &date,
+                 const QString &content, const QString &comment, bool odd);
 
     virtual void setFont(const QFont &font);
     virtual int cellWidth(int col);
