@@ -27,15 +27,6 @@
 #include "commitdlg.moc"
 
 
-// Argl, in Qt 1.x QListBox::item is protected :-(
-class MyQListBox : public QListBox
-{
-public:
-   QListBoxItem *item(int index) const
-   { return QListBox::item(index); }
-};
-
-
 CommitDialog::Options *CommitDialog::options = 0;
 
 
@@ -196,8 +187,7 @@ void CommitDialog::comboActivated(int index)
 
 void CommitDialog::fileSelected(int index)
 {
-    MyQListBox *lb = static_cast<MyQListBox*>(listbox);
-    QListBoxItem *item = lb->item(index);
+    QListBoxItem *item = listbox->item(index);
     if ( !item )
         return;
     QString filename = item->text();
