@@ -17,10 +17,12 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qkeycode.h>
+#include <qfileinfo.h>
 #include <kbuttonbox.h>
 #include <kapp.h>
-#include <klocale.h>
 #include <kconfig.h>
+#include <klocale.h>
+#include <ktempfile.h>
 #include <kprocess.h>
 #include "misc.h"
 #include "cvsprogressdlg.h"
@@ -269,6 +271,69 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
     
     KConfig *config = kapp->config();
     config->setGroup("General");
+
+    // Ok, this is a hack: When the user wants an external diff
+    // front end, it is executed from here. Of course, in that
+    // case this dialog wouldn't have to be created in the first
+    // place, but this design at least makes the handling trans-
+    // parent for the calling routines
+
+    QString extdiff = config->readEntry("ExternalDiff", "");
+    if (!extdiff.isEmpty())
+        {
+            QString cmdline = "cvs update -p ";
+            QString extcmdline = extdiff;
+            extcmdline += " ";
+            
+            if (!revA.isEmpty() && !revB.isEmpty())
+                {
+                    // We're comparing two revisions
+                    QString revAFilename = tempFileName(QString("-")+revA);
+                    QString revBFilename = tempFileName(QString("-")+revB);
+                    cmdline += " -r ";
+                    cmdline += revA;
+                    cmdline += " ";
+                    cmdline += KShellProcess::quote(filename);
+                    cmdline += " > ";
+                    cmdline += revAFilename;
+                    cmdline += " ; cvs update -p ";
+                    cmdline += " -r ";
+                    cmdline += revB;
+                    cmdline += " ";
+                    cmdline += KShellProcess::quote(filename);
+                    cmdline += " > ";
+                    cmdline += revBFilename;
+                    
+                    extcmdline += revAFilename;
+                    extcmdline += " ";
+                    extcmdline += revBFilename;
+                } else {
+                    // We're comparing to a file, and perhaps one revision
+                    QString revAFilename = tempFileName(revA);
+                    if (!revA.isEmpty())
+                        {
+                            cmdline += " -r ";
+                            cmdline += revA;
+                        }
+                    cmdline += " ";
+                    cmdline += KShellProcess::quote(filename);
+                    cmdline += " > ";
+                    cmdline += revAFilename;
+                    
+                    extcmdline += revAFilename;
+                    extcmdline += " ";
+                    extcmdline += KShellProcess::quote(QFileInfo(filename).absFilePath());
+                }
+            CvsProgressDialog l("Diff", this);
+            if (l.execCommand(sandbox, repository, cmdline, "diff"))
+                {
+                    KShellProcess proc("/bin/sh");
+                    proc << extcmdline;
+                    proc.start(KProcess::DontCare);
+                }
+            return false;
+        }
+
     QString cmdline = cvsClient() + " -f diff ";
     cmdline += config->readEntry("DiffOptions", "");
     cmdline += " -U ";
