@@ -16,10 +16,12 @@
 #define _DIFFDLG_H_
 
 #include <qdialog.h>
-#include <qlabel.h>
-#include <qmultilinedit.h>
-#include <qcheckbox.h>
-#include "diffview.h"
+
+class QLabel;
+class QCheckBox;
+class QComboBox;
+class DiffItem;
+class DiffView;
 
 
 class DiffDialog : public QDialog
@@ -29,9 +31,9 @@ class DiffDialog : public QDialog
 public:
     DiffDialog( QWidget *parent=0, const char *name=0, bool modal=false );
 
-    bool parseCvsDiff(QString sandbox, QString repository,
-                      QString filename, QString revA, QString revB);
-    void updateViews();
+    bool parseCvsDiff(const QString &sandbox, const QString &repository,
+                      const QString &filename, const QString &revA, const QString &revB);
+    //    void updateViews();
 
     static void loadOptions(KConfig *config);
     static void saveOptions(KConfig *config);
@@ -44,6 +46,9 @@ protected:
 
 private slots:
     void toggleSynchronize(bool b);
+    void comboActivated(int index);
+    void backClicked();
+    void forwClicked();
     
 private:
     struct Options {
@@ -52,9 +57,17 @@ private:
     };
     static Options *options;
 
-    QLabel *revlabel1, *revlabel2;
-    DiffView *diff1, *diff2;
+    void updateNofN();
+    void updateHighlight(int newitem);
+
+    QLabel *revlabel1, *revlabel2, *nofnlabel;
     QCheckBox *syncbox;
+    QComboBox *itemscombo;
+    QPushButton *backbutton, *forwbutton;
+    DiffView *diff1, *diff2;
+
+    QList<DiffItem> items;
+    int markeditem;
 };
 
 #endif
