@@ -424,21 +424,22 @@ void DiffZoomWidget::paintEvent(QPaintEvent *)
             for (int i=0; i < (int)str.size(); ++i)
                 {
                     char c = str[i];
-                    QColor color =
-                        (c==' ')? gray
-                        : (c=='C')? QColor(237, 190, 190)
-                        : (c=='I')? QColor(190, 190, 237)
-                        : (c=='D')? QColor(190, 237, 190)
-                        : (c=='N')? gray : white;
+		    int	y1 = (int)(i*scale);
                     int y2 = (int)((i+1)*scale);
                     if (y1 != y0 || c != 'U')
                         {
+                            QColor color =
+                              (c==' ')? gray
+                              : (c=='C')? QColor(237, 190, 190)
+                              : (c=='I')? QColor(190, 190, 237)
+                              : (c=='D')? QColor(190, 237, 190)
+                              : (c=='N')? gray : white;
+			    
                             if (y2 == y1)
                                 y2++;
                             p.fillRect(0, sliderMin+y1, pixbuf.width(), y2-y1, QBrush(color));
                             y0 = y1;
                         }
-                    y1 = y2;
                 }
         }
     p.flush();
