@@ -220,7 +220,7 @@ bool LogDialog::parseCvsLog(const QString &sbox, const QString &repo, const QStr
     
     setCaption("CVS Log: " + filename);
 
-    QString cmdline = cvsClient() + " log ";
+    QString cmdline = cvsClient() + " -f log ";
     cmdline += KShellProcess::quote(filename);
     
     CvsProgressDialog l("Logging", this);
@@ -396,6 +396,8 @@ void LogDialog::diffClicked()
 				     i18n("Please select revisions A and B first."));
 	    return;
 	}
+
+    // Non-modal dialog
     DiffDialog *l = new DiffDialog();
     if (l->parseCvsDiff(sandbox, repository, filename, selectionA, selectionB))
         l->show();
