@@ -22,6 +22,7 @@
 #include <kfiledialog.h>
 #include <klocale.h>
 
+#include "misc.h"
 #include "toplevel.h"
 #include "../config.h"
 
@@ -56,7 +57,9 @@ int main(int argc, char **argv)
         t->show();
     }
     
-    return app->exec();
+    int res = app->exec();
+    cleanupTempFiles();
+    return res;
 }
 
 
