@@ -20,6 +20,7 @@
 #include <kapp.h>
 #include <kconfig.h>
 #include <kprocess.h>
+#include <ktempfile.h>
 #include "misc.h"
 
 
@@ -113,6 +114,31 @@ QString userName()
     return res;
 }
 
+
+static QStringList *tempFiles = 0;
+
+void cleanupTempFiles()
+{
+    if (tempFiles)
+        {
+            QStringList::Iterator it;
+            for (it = tempFiles->begin(); it != tempFiles->end(); ++it)
+                QFile::remove(*it);
+            delete tempFiles;
+        }
+}
+
+
+QString tempFileName(const QString &suffix)
+{
+    if (!tempFiles)
+        tempFiles = new QStringList;
+    
+    KTempFile f(QString::null, suffix);
+    tempFiles->append(f.name());
+    return f.name();
+}
+
 // Local Variables:
 // c-basic-offset: 4
 // End:
