@@ -19,12 +19,13 @@
 
 
 void chomp(QCString *line);
-//QString quote(const QString &str);
 QString joinLine(const QStringList &list);
 QStringList splitLine(QString, char delim=' ');
 bool isValidTag(const QString &str);
 QString cvsClient();
 QString userName();
+QString tempFileName(const QString &suffix);
+void cleanupTempFiles();
 
 #ifdef NDEBUG
 #define DEBUGOUT(x)
