@@ -27,7 +27,7 @@ public:
     ProtocolView( QWidget *parent=0, const char *name=0 );
     ~ProtocolView();
 
-    bool startJob(QString sandbox, QString repository, QString cmdline);
+    bool startJob(const QString &sandbox, const QString &repository, const QString &cmdline);
 
 signals:
     void receivedLine(QString line);
