@@ -1,4 +1,4 @@
-/* 
+/*
  *  Copyright (C) 1999-2001 Bernd Gehrmann
  *                          bernd@physik.hu-berlin.de
  *
@@ -68,14 +68,21 @@ ResolveDialog::ResolveDialog( QWidget *parent, const char *name)
     merge = new DiffView(false, false, this);
     layout->addWidget(merge, 10);
 
-    QPushButton *abutton = new QPushButton("&A", this);
+    abutton = new QPushButton("&A", this);
     connect( abutton, SIGNAL(clicked()), SLOT(aClicked()) );
     
-    QPushButton *bbutton = new QPushButton("&B", this);
+    bbutton = new QPushButton("&B", this);
     connect( bbutton, SIGNAL(clicked()), SLOT(bClicked()) );
 
-    //    nofnlabel = new QLabel(i18n("10 conflicts"), this);
-    //    nofnlabel->setFixedSize(nofnlabel->sizeHint());
+    abbutton = new QPushButton("A+B", this);
+    connect( abbutton, SIGNAL(clicked()), SLOT(abClicked()) );
+
+    babutton = new QPushButton("B+A", this);
+    connect( babutton, SIGNAL(clicked()), SLOT(baClicked()) );
+
+    editbutton = new QPushButton("&Edit", this);
+    connect( editbutton, SIGNAL(clicked()), SLOT(editClicked()) );
+
     nofnlabel = new QLabel(this);
     nofnlabel->setAlignment(AlignCenter);
     
@@ -89,6 +96,9 @@ ResolveDialog::ResolveDialog( QWidget *parent, const char *name)
     layout->addLayout(buttonlayout);
     buttonlayout->addWidget(abutton, 1);
     buttonlayout->addWidget(bbutton, 1);
+    buttonlayout->addWidget(abbutton, 1);
+    buttonlayout->addWidget(babutton, 1);
+    buttonlayout->addWidget(editbutton, 1);
     buttonlayout->addStretch(1);
     buttonlayout->addWidget(nofnlabel, 2);
     buttonlayout->addStretch(1);
@@ -129,8 +139,8 @@ void ResolveDialog::done(int res)
     QDialog::done(res);
     delete this;
 }
-
 	    
+
 void ResolveDialog::loadOptions(KConfig *config)
 {
     if (!config->readEntry("Customized"))
@@ -161,10 +171,11 @@ class ResolveItem
 public:
     int linenoA, linecountA;
     int linenoB, linecountB;
+    int linecountTotal;
     int offsetM;
-    bool chosenA;
+    ResolveDialog::ChooseType chosen;
 };
-    
+
 
 bool ResolveDialog::parseFile(const QString &name)
 {
@@ -205,7 +216,8 @@ bool ResolveDialog::parseFile(const QString &name)
 		    item->linenoB = lineno2-advanced2+1;
 		    item->linecountB = advanced2;
 		    item->offsetM = item->linenoA-1;
-		    item->chosenA = true;
+		    item->chosen = ChA;
+                    item->linecountTotal = item->linecountA;
 		    items.append(item);
 		    for (; advanced1 < advanced2; advanced1++)
 			diff1->addLine("", DiffView::Neutral);
@@ -272,6 +284,13 @@ void ResolveDialog::updateNofN()
 
     backbutton->setEnabled(markeditem != -1);
     forwbutton->setEnabled(markeditem != -2 && items.count());
+
+    bool marked = markeditem >= 0;
+    abutton->setEnabled(marked);
+    bbutton->setEnabled(marked);
+    abbutton->setEnabled(marked);
+    babutton->setEnabled(marked);
+    editbutton->setEnabled(marked);
 }
 
 
@@ -297,9 +316,11 @@ void ResolveDialog::updateHighlight(int newitem)
 		diff2->setInverted(i, true);
 	    diff1->setCenterLine(item->linenoA);
 	    diff2->setCenterLine(item->linenoB);
+            merge->setCenterOffset(item->offsetM);
 	}
     diff1->repaint();
     diff2->repaint();
+    merge->repaint();
     updateNofN();
 }
 
@@ -330,46 +351,73 @@ void ResolveDialog::forwClicked()
 }
 
 
-void ResolveDialog::chooseAorB(bool a)
+void ResolveDialog::choose(ChooseType ch)
 {
+    DiffView *first=0, *second=0;
+    int firstno=0, secondno=0;
+    int firstcount=0, secondcount=0;
+  
     if (markeditem < 0)
 	return;
 
     ResolveItem *item = items.at(markeditem);
-    if ( (item->chosenA && a) || (!item->chosenA && !a) )
+    if (item->chosen == ch)
 	return;
 
-    int difference = item->linecountA - item->linecountB;
-    if (!a)
-	difference = -difference;
+    switch (ch)
+        {
+        case ChA:
+            first = diff1; 
+            firstno = item->linenoA;
+            firstcount = item->linecountA;
+            break;
+        case ChB:
+            first = diff2; 
+            firstno = item->linenoB;
+            firstcount = item->linecountB;
+            break;
+        case ChAB:
+            first = diff1; 
+            firstno = item->linenoA;
+            firstcount = item->linecountA;
+            second = diff2; 
+            secondno = item->linenoB;
+            secondcount = item->linecountB;
+            break;
+        case ChBA:
+            first = diff2; 
+            firstno  = item->linenoB;
+            firstcount = item->linecountB;
+            second = diff1; 
+            secondno = item->linenoA;
+            secondcount = item->linecountA;
+            break;
+        default:
+            DEBUGOUT("Internal error at switch");
+        }
 
+    int total = firstcount + secondcount;
+    int difference = total - item->linecountTotal;
+    
     // Remove old variant
-    for (int i = 0; i < (a?item->linecountB:item->linecountA); ++i)
-	{
-	    //	    DEBUGOUT( "Remove offset " << item->offsetM );
-	    merge->removeAtOffset(item->offsetM);
-	}
+    for (int i = 0; i < item->linecountTotal; ++i)
+        merge->removeAtOffset(item->offsetM);
+
     // Insert new
-    for (int i = 0; i < (a?item->linecountA:item->linecountB); ++i)
-	{
-	    QString newline = a?
-		diff1->stringAtLine(item->linenoA+i)
-		: diff2->stringAtLine(item->linenoB+i);
-            //	    DEBUGOUT( "Insert from line " << (a? (item->linenoA+i) : (item->linenoB+i)) );
-            //	    DEBUGOUT( "at offset " << item->offsetM+i);
-	    merge->insertAtOffset(newline, DiffView::Change, item->offsetM+i);
-	}
-    //    merge->setCenterOffset(item->offsetM);
-    item->chosenA = a;
+    for (int i = 0; i < firstcount; ++i)
+        merge->insertAtOffset(first->stringAtLine(firstno+i), DiffView::Change, item->offsetM+i);
+    
+    if (second)
+        for (int i = 0; i < secondcount; ++i)
+            merge->insertAtOffset(second->stringAtLine(secondno+i), DiffView::Change, item->offsetM+firstcount+i);
+    
+    item->chosen = ch;
+    item->linecountTotal = total;
     
     // Adjust other items
     while ( (item = items.next()) != 0 )
-	{
-            //	    DEBUGOUT( "Adjusting at offset " << item->offsetM );
-	    item->offsetM += difference;
-	}
-	
-    //    merge->setAutoUpdate(true);
+        item->offsetM += difference;
+    
     merge->repaint();
     
 }
@@ -377,13 +425,66 @@ void ResolveDialog::chooseAorB(bool a)
 
 void ResolveDialog::aClicked()
 {
-    chooseAorB(true);
+    choose(ChA);
 }
 
 
 void ResolveDialog::bClicked()
 {
-    chooseAorB(false);
+    choose(ChB);
+}
+
+
+void ResolveDialog::abClicked()
+{
+    choose(ChAB);
+}
+
+
+void ResolveDialog::baClicked()
+{
+    choose(ChBA);
+}
+
+
+void ResolveDialog::editClicked()
+{
+    if (markeditem < 0)
+        return;
+    ResolveItem *item = items.at(markeditem);
+
+    QStringList oldContent;
+    for (int i = 0; i < item->linecountTotal; ++i)
+        oldContent << merge->stringAtOffset(item->offsetM+i);
+
+    ResolveEditorDialog *dlg = new ResolveEditorDialog(this, "edit");
+    dlg->setContent(oldContent);
+    
+    if (dlg->exec())
+        {
+            QStringList newContent = dlg->content();
+            int total = newContent.count();
+            int difference = total - item->linecountTotal;
+            
+            // Remove old variant
+            for (int i = 0; i < item->linecountTotal; ++i)
+                merge->removeAtOffset(item->offsetM);
+            
+            // Insert new
+            for (int i = 0; i < total; ++i)
+                merge->insertAtOffset(newContent[i], DiffView::Change, item->offsetM+i);
+            
+            item->chosen = ChEdit;
+            item->linecountTotal = total;
+            
+            // Adjust other items
+            while ( (item = items.next()) != 0 )
+                item->offsetM += difference;
+            
+            merge->repaint();
+        }
+    
+    delete dlg;
 }
 
 
@@ -416,9 +517,92 @@ void ResolveDialog::keyPressEvent(QKeyEvent *e)
 	}
 }
 
+ResolveEditorDialog::Options *ResolveEditorDialog::options = 0;
+
+
+ResolveEditorDialog::ResolveEditorDialog(QWidget *parent, const char *name)
+    : QDialog(parent, name, true,
+              WStyle_Customize|WStyle_NormalBorder|WStyle_Title|WStyle_MinMax)
+{
+    QFontMetrics fm(fontMetrics());
+
+    QBoxLayout *layout = new QVBoxLayout(this, 10);
+
+    setMinimumSize(fm.width("0123456789")*120,
+		   fm.lineSpacing()*120);
+
+    edit = new QMultiLineEdit(this);
+    edit->setFocus();
+    layout->addWidget(edit, 10);
+  
+    QFrame *frame = new QFrame(this);
+    frame->setFrameStyle(QFrame::HLine | QFrame::Sunken);
+    frame->setMinimumHeight(frame->sizeHint().height());
+    layout->addWidget(frame, 0);
+    
+    KButtonBox *buttonbox = new KButtonBox(this);
+    buttonbox->addStretch();
+    QPushButton *ok = buttonbox->addButton(i18n("&OK"));
+    QPushButton *cancel = buttonbox->addButton(i18n("Cancel"));
+    ok->setDefault(true);
+    connect( ok, SIGNAL(clicked()), this, SLOT(accept()) );
+    connect( cancel, SIGNAL(clicked()), this, SLOT(reject()) );
+    buttonbox->layout();
+    layout->addWidget(buttonbox, 0);
+    layout->activate();
+
+    if (options)
+        resize(options->size);
+}
+
+
+void ResolveEditorDialog::done(int r)
+{
+    if (!options)
+        options = new Options;
+    options->size = size();
+    QDialog::done(r);
+}
+
+
+void ResolveEditorDialog::loadOptions(KConfig *config)
+{
+    if (!config->readEntry("Customized"))
+        return;
+
+    options = new Options;
+    options->size = config->readSizeEntry("Size");
+}
+
+
+void ResolveEditorDialog::saveOptions(KConfig *config)
+{
+    if (!options)
+        return;
+
+    config->writeEntry("Customized", true);
+    config->writeEntry("Size", options->size);
+}
+
+
+void ResolveEditorDialog::setContent(const QStringList &l)
+{
+    QStringList::ConstIterator it;
+    for (it = l.begin(); it != l.end(); ++it)
+        edit->insertLine((*it).left((*it).length()-1));
+}
+
+
+QStringList ResolveEditorDialog::content() const
+{
+    QStringList l;
+    for (int i = 0; i < edit->numLines(); ++i)
+        l << (edit->textLine(i) + '\n');
+
+    return l;
+}
+
 
 // Local Variables:
 // c-basic-offset: 4
 // End:
-
-
