@@ -22,7 +22,6 @@
 #include <qlist.h>
 #include "diffview.h"
 
-
 class ResolveItem;
 
 class ResolveDialog : public QDialog
@@ -30,6 +29,8 @@ class ResolveDialog : public QDialog
     Q_OBJECT
 
 public:
+    enum ChooseType { ChA, ChB, ChAB, ChBA, ChEdit };
+
     ResolveDialog( QWidget *parent=0, const char *name=0 );
 
     bool parseFile(const QString &name);
@@ -46,6 +47,9 @@ private slots:
     void forwClicked();
     void aClicked();
     void bClicked();
+    void abClicked();
+    void baClicked();
+    void editClicked();
     void slotSave();
     void slotSaveAs();
     
@@ -57,11 +61,13 @@ private:
 
     void updateNofN();
     void updateHighlight(int newitem);
-    void chooseAorB(bool a);
+    void choose(ChooseType ch);
+    void chooseEdit();
     void saveFile(const QString &name);
     
     QLabel *nofnlabel;
     QPushButton *backbutton, *forwbutton;
+    QPushButton *abutton, *bbutton, *abbutton, *babutton, *editbutton;
     DiffView *diff1, *diff2, *merge;
 
     QList<ResolveItem> items;
@@ -69,6 +75,32 @@ private:
     int markeditem;
 };
 
+
+class ResolveEditorDialog : public QDialog
+{
+    Q_OBJECT
+  
+public:
+    ResolveEditorDialog( QWidget *parent=0, const char *name=0 );
+
+    void setContent(const QStringList &l);
+    QStringList content() const;
+
+    static void loadOptions(KConfig *config);
+    static void saveOptions(KConfig *config);
+    
+protected:
+    virtual void done(int r);
+
+private:
+    struct Options {
+        QSize size;
+    };
+    static Options *options;
+    
+    QMultiLineEdit *edit;
+};  
+
 #endif
 
 
