@@ -18,10 +18,10 @@
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qwidgetlist.h>
-#include <kapp.h>
 #include <kbuttonbox.h>
 #include <kconfig.h>
 #include <kfontdialog.h>
+#include <kglobal.h>
 #include <klocale.h>
 #include <knuminput.h>
 
@@ -111,7 +111,6 @@ SettingsDialog::SettingsDialog(QWidget *parent, const char *name)
     contextedit = new KIntNumInput(0, diffgroup);
     contextedit->setRange(0, 65535, 1, false);
     contextlabel->setBuddy(contextedit);
-    contextedit->setMinimumSize(contextedit->sizeHint());
     difflayout->addWidget(contextedit);
     difflayout->addSpacing(5);
 
@@ -121,7 +120,6 @@ SettingsDialog::SettingsDialog(QWidget *parent, const char *name)
 
     diffoptedit = new QLineEdit(diffgroup);
     diffoptlabel->setBuddy(diffoptedit);
-    diffoptedit->setMinimumSize(diffoptedit->sizeHint());
     difflayout->addWidget(diffoptedit);
 
     QLabel *tabwidthlabel = new QLabel(i18n("Tab&width in diff dialog:"), diffgroup);
@@ -133,6 +131,13 @@ SettingsDialog::SettingsDialog(QWidget *parent, const char *name)
     difflayout->addWidget(tabwidthedit);
     difflayout->addSpacing(5);
 
+    QLabel *extdifflabel = new QLabel(i18n("External diff &frontend:"), diffgroup);
+    difflayout->addWidget(extdifflabel);
+
+    extdiffedit = new QLineEdit(diffgroup);
+    extdifflabel->setBuddy(extdiffedit);
+    difflayout->addWidget(extdiffedit);
+    
     difflayout->activate();
     
     QGroupBox *statusgroup = new QGroupBox(i18n("Status"), this);
@@ -254,14 +259,15 @@ SettingsDialog::SettingsDialog(QWidget *parent, const char *name)
 
 void SettingsDialog::readSettings()
 {
-    KConfig *config = kapp->config();
+    KConfig *config = KGlobal::config();
     config->setGroup("General");
     timeoutedit->setValue((int)config->readUnsignedNumEntry("Timeout", 4000));
     usernameedit->setText(config->readEntry("Username", userName()));
     cvspathedit->setText(config->readEntry("CVSPath", "cvs"));
     contextedit->setValue((int)config->readUnsignedNumEntry("ContextLines", 65535));
-    diffoptedit->setText(config->readEntry("DiffOptions", ""));
     tabwidthedit->setValue((int)config->readUnsignedNumEntry("TabWidth", 8));
+    diffoptedit->setText(config->readEntry("DiffOptions", ""));
+    extdiffedit->setText(config->readEntry("ExternalDiff", ""));
     remotestatusbox->setChecked(config->readBoolEntry("StatusForRemoteRepos", false));
     localstatusbox->setChecked(config->readBoolEntry("StatusForLocalRepos", false));
     config->setGroup("Communication");
@@ -284,7 +290,7 @@ void SettingsDialog::readSettings()
 
 void SettingsDialog::writeSettings()
 {
-    KConfig *config = kapp->config();
+    KConfig *config = KGlobal::config();
     config->setGroup("General");
     config->writeEntry("Timeout", (unsigned)timeoutedit->value());
     config->writeEntry("Username", usernameedit->text());
@@ -292,6 +298,7 @@ void SettingsDialog::writeSettings()
     config->writeEntry("ContextLines", (unsigned)contextedit->value());
     config->writeEntry("TabWidth", tabwidthedit->value());
     config->writeEntry("DiffOptions", diffoptedit->text());
+    config->writeEntry("ExternalDiff", extdiffedit->text());
     config->writeEntry("StatusForRemoteRepos", remotestatusbox->isChecked());
     config->writeEntry("StatusForLocalRepos", localstatusbox->isChecked());
     config->setGroup("Communication");
