@@ -190,7 +190,7 @@ void TopLevel::setupMenuBar()
 
     file->insertSeparator();
     
-    file_open    = file->insertItem( BarIcon("fileopen.xpm"), i18n("&Open..."),
+    file_open    = file->insertItem( BarIcon("fileopen"), i18n("&Open..."),
                                      this, SLOT(slotOpen()) );
     file_resolv  = file->insertItem( i18n("Reso&lve..."),
                                      this, SLOT(slotResolve()) );
@@ -210,7 +210,7 @@ void TopLevel::setupMenuBar()
 
     file->insertSeparator();
 
-    file_exit   = file->insertItem( BarIcon("exit.xpm"), i18n("&Quit"),
+    file_exit   = file->insertItem( BarIcon("exit"), i18n("&Quit"),
                                     this, SLOT(slotExit()) );
 
     //
@@ -380,27 +380,27 @@ void TopLevel::setupToolBar()
 {
     KToolBar *toolbar = toolBar();
 
-    toolbar->insertButton( BarIcon("up.xpm"), 101, SIGNAL(clicked()),
+    toolbar->insertButton( BarIcon("up"), 101, SIGNAL(clicked()),
                            this, SLOT(slotCommit()),
                            true, i18n("Commit") );
 
-    toolbar->insertButton( BarIcon("down.xpm"), 102, SIGNAL(clicked()),
+    toolbar->insertButton( BarIcon("down"), 102, SIGNAL(clicked()),
                            this, SLOT(slotUpdate()),
                            true, i18n("Update") );
 
     toolbar->insertSeparator();
     
-    toolbar->insertButton( BarIcon("fileopen.xpm"), 103, SIGNAL(clicked()),
+    toolbar->insertButton( BarIcon("fileopen"), 103, SIGNAL(clicked()),
                            this, SLOT(slotOpen()),
                            true, i18n("Open file") );
     
-    toolbar->insertButton( BarIcon("help.xpm"), 104, SIGNAL(clicked()),
+    toolbar->insertButton( BarIcon("help"), 104, SIGNAL(clicked()),
                            this, SLOT(slotHelp()),
                            true, i18n("Help") );
 
     toolbar->insertSeparator();
     
-    toolbar->insertButton( BarIcon("stop.xpm"), 42, SIGNAL(clicked()),
+    toolbar->insertButton( BarIcon("stop"), 42, SIGNAL(clicked()),
                            protocol, SLOT(cancelJob()),
                            false, i18n("Stop") );
 }
@@ -486,11 +486,10 @@ void TopLevel::popupRequested()
                                     this, SLOT(slotAdd()) );
     int id_remove = pop.insertItem( i18n("&Remove from Repository..."),
                                     this, SLOT(slotRemove()) );
-
-    int numselected = update->numSelections();
-    pop.setItemEnabled(id_open, (numselected >= 1));
-    pop.setItemEnabled(id_resolv, (numselected == 1));
-
+    (void) id_open;
+    
+    bool single = update->hasSingleSelection();
+    pop.setItemEnabled(id_resolv, single);
     bool nojob = !toolBar()->getButton(42)->isEnabled();
     pop.setItemEnabled(id_commit, nojob);
     pop.setItemEnabled(id_add, nojob);
@@ -501,12 +500,8 @@ void TopLevel::popupRequested()
 
 void TopLevel::updateMenu()
 {
-    int num = update->numSelections();
-    bool single = false;
-    if( num == 1 ) single = true;
-
+    bool single = update->hasSingleSelection();
     toolBar()->getButton(103)->setEnabled(single);
-    file->setItemEnabled(file_open, (num >= 1) );
 
     file->setItemEnabled(file_resolv, single);
     view->setItemEnabled(view_log, single);
@@ -587,7 +582,9 @@ void TopLevel::slotChangeLog()
 
 void TopLevel::slotOpen()
 {
-    QStringList filenames = update->multipleSelection();
+    QStringList filenames = update->fileSelection();
+    if (filenames.isEmpty())
+        return;
     openFiles(filenames);
 }
 
@@ -596,14 +593,14 @@ void TopLevel::openFile(QString filename)
 {
     QStringList files;
     files << filename;
-    openFiles( files );
+    openFiles(files);
 }
 
 
 void TopLevel::openFiles(const QStringList &filenames)
 {
     // First check the cvs edit stuff
-    if (opt_doCVSEdit) // && !QFileInfo(filename).isWritable())
+    if (opt_doCVSEdit)
         {
             CvsProgressDialog l("Edit", this);
             l.setCaption("CVS Edit");
@@ -634,26 +631,10 @@ void TopLevel::openFiles(const QStringList &filenames)
     KShellProcess proc("/bin/sh");
     proc << config->readEntry("Editor", "kwrite");
 
-    QString path;
-    bool run = false;
     for ( QStringList::ConstIterator it = filenames.begin();
           it != filenames.end(); ++it )
-    {
-        //make sure that the file is a file, not a directory
-        path = sandbox + "/" + *it;
-        kdDebug() << "examing: " << path << endl;
-
-        KFileItem info( -1, -1, KURL( path ) );
-        if( !info.isDir() )
-        {
-            kdDebug() << "file is not a dir" << endl;
-            run = true;
-            proc << KShellProcess::quote( path );
-        }
-    }
-
-    if( run )
-        proc.start(KProcess::DontCare);
+        proc << KShellProcess::quote(*it);
+    proc.start(KProcess::DontCare);
 }
 
 
@@ -1369,7 +1350,7 @@ void TopLevel::slotDoCVSEdit()
 void TopLevel::slotConfigure()
 {
     SettingsDialog *l = new SettingsDialog(this);
-    l->show();
+    l->exec();
 
     KConfig *config = kapp->config();
     config->setGroup("LookAndFeel");
@@ -1649,6 +1630,8 @@ bool TopLevel::queryExit()
     LogListView::saveOptions(config);
     config->setGroup("Resolve dialog");
     ResolveDialog::saveOptions(config);
+    config->setGroup("Resolve edit dialog");
+    ResolveEditorDialog::saveOptions(config);
     config->setGroup("Commit dialog");
     CommitDialog::saveOptions(config);
     config->setGroup("ChangeLog dialog");
@@ -1700,6 +1683,8 @@ void TopLevel::restorePseudo(const QString &dirname)
     LogListView::loadOptions(config);
     config->setGroup("Resolve dialog");
     ResolveDialog::loadOptions(config);
+    config->setGroup("Resolve edit dialog");
+    ResolveEditorDialog::loadOptions(config);
     config->setGroup("Commmit dialog");
     CommitDialog::loadOptions(config);
     config->setGroup("ChangeLog dialog");
