@@ -694,26 +694,23 @@ UpdateView::Filter UpdateView::filter() const
 
 bool UpdateView::hasSingleSelection()
 {
-    return numSelections() == 1;
-}
-
-
-int UpdateView::numSelections()
-{
-    int num = 0;
-    
+    bool selfound = false;
     QStack<QListViewItem> s;
+
     for ( QListViewItem *item = firstChild(); item;
 	  item = item->nextSibling()? item->nextSibling() : s.pop() )
 	{
 	    if (item->firstChild())
-                s.push(item->firstChild());
-            
+		    s.push(item->firstChild());
+
 	    if (item->isSelected())
-                ++num;
+		{
+		    if (selfound || item->isExpandable())
+			return false;
+		    selfound = true;
+		}
 	}
-    
-    return num;
+    return selfound;
 }
 
 
@@ -736,6 +733,7 @@ void UpdateView::getSingleSelection(QString *filename, QString *revision)
 	}
 }
 
+
 QStringList UpdateView::multipleSelection()
 {
     QStringList res;
@@ -766,21 +764,22 @@ QStringList UpdateView::multipleSelection()
 }
 
 
-#if 0
-void UpdateView::deselectAll()
+QStringList UpdateView::fileSelection()
 {
+    QStringList res;
     QStack<QListViewItem> s;
+
     for ( QListViewItem *item = firstChild(); item;
-	  item = item->nextSibling()? item->nextSibling() : s.pop() )
-	{
-	    if (item->firstChild())
-		s.push(item->firstChild());
-	    item->setSelected(false);
-	}
-    
-    triggerUpdate();
+          item = item->nextSibling()? item->nextSibling() : s.pop() )
+        {
+            if (item->firstChild())
+                s.push(item->firstChild());
+
+            if (item->isSelected() && !isDirItem(item))
+                res.append( static_cast<UpdateViewItem*>(item)->filePath() );
+        }
+    return res;
 }
-#endif
 
 
 void UpdateView::unfoldTree()
