@@ -40,10 +40,12 @@ public:
     
     static bool isDirItem(QListViewItem *item);
 
-    int  numSelections();
     bool hasSingleSelection();
     void getSingleSelection(QString *filename, QString *revision=0);
+    /* Returns a list of all marked files and directories */
     QStringList multipleSelection();
+    /* Returns a list of all marked files, excluding directories*/
+    QStringList fileSelection();
 
     void openDirectory(QString dirname);
     void scanRecursive();
